Method: Metior::Actor#authored_commits

Defined in:
lib/metior/actor.rb

#authored_commitsCommitCollection (readonly) Also known as: commits

Returns The list of commits this actor has contributed to the source code repository.

Returns:

  • (CommitCollection)

    The list of commits this actor has contributed to the source code repository



24
25
26
# File 'lib/metior/actor.rb', line 24

def authored_commits
  @authored_commits
end