Method: Metior::Repository#top_authors

Defined in:
lib/metior/repository.rb

#top_authors(range = self.class::DEFAULT_BRANCH, count = 3) ⇒ Array<Actor> Also known as: top_contributors

Returns a list of top contributors in the given commit range

This will first have to load all authors (and i.e. commits) from the given commit range.

Parameters:

  • range (String, Range) (defaults to: self.class::DEFAULT_BRANCH)

    The range of commits for which the top contributors should be retrieved. This may be given as a string ('master..development'), a range ('master'..'development') or as a single ref ('master'). A single ref name means all commits reachable from that ref.

  • count (Fixnum) (defaults to: 3)

    The number of contributors to return

Returns:

  • (Array<Actor>)

    An array of the given number of top contributors in the given commit range

See Also:



284
285
286
# File 'lib/metior/repository.rb', line 284

def top_authors(range = self.class::DEFAULT_BRANCH, count = 3)
  authors(range).top(count)
end