Method: Metior::Repository#top_authors
- Defined in:
- lib/metior/repository.rb
#top_authors(range = self.class::DEFAULT_BRANCH, count = 3) ⇒ Array<Actor> Also known as: top_contributors
Returns a list of top contributors in the given commit range
This will first have to load all authors (and i.e. commits) from the given commit range.
284 285 286 |
# File 'lib/metior/repository.rb', line 284 def (range = self.class::DEFAULT_BRANCH, count = 3) (range).top(count) end |